@@ -73,15 +73,15 @@ pub use block::*;
 #[cfg(feature = "testnet1")]
 pub mod testnet1;
 
+#[cfg(feature = "testnet2")]
+pub mod testnet2;
+
 pub mod errors;
 pub use errors::*;
 
 pub mod traits;
 pub use traits::*;
 
-#[cfg(test)]
-mod tests;
-
 pub mod prelude {
     pub use crate::{account::*, block::*, errors::*, traits::*};
 }
